/*
 *
 * Inter Asterisk Exchange 2
 * 
 * Base include file of iax.
 *
 * Open Phone Abstraction Library (OPAL)
 *
 * Copyright (c) 2005 Indranet Technologies Ltd.
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.0 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific language governing rights and limitations
 * under the License.
 *
 * The Original Code is Open Phone Abstraction Library.
 *
 * The Initial Developer of the Original Code is Indranet Technologies Ltd.
 *
 * The author of this code is Derek J Smithies
 *
 *
 * Contributor(s): ______________________________________.
 *
 * $Revision: 29536 $
 * $Author: rjongbloed $
 * $Date: 2013-04-19 09:55:15 +0100 (Fri, 19 Apr 2013) $
 */

#ifndef OPAL_IAX2_IAX2_H
#define OPAL_IAX2_IAX2_H

#include <opal_config.h>

#if OPAL_IAX2

#include <iax2/iax2ep.h>
#include <iax2/iax2con.h>

#endif // OPAL_IAX2

#endif // OPAL_IAX2_IAX2_H


// End of File ///////////////////////////////////////////////////////////////
